export default class AsyncQueue {
    queue = [];
    resolve = undefined;
    promise = new Promise((resolve) => (this.resolve = resolve));
    isDone = false;
    constructor(iterable) {
        if (iterable) {
            this.queue.push(...iterable);
        }
    }
    async *[Symbol.asyncIterator]() {
        while (true) {
            if (this.queue.length) {
                yield this.queue.shift();
            }
            else if (this.isDone) {
                break;
            }
            else {
                await this.promise;
            }
        }
    }
    push(...values) {
        this.queue.push(...values);
        this.resolve?.();
        this.promise = new Promise((resolve) => (this.resolve = resolve));
    }
    done() {
        this.isDone = true;
        this.resolve?.();
    }
    get size() {
        return this.queue.length;
    }
}
//# sourceMappingURL=AsyncQueue.js.map